@@ -22,12 +22,12 @@ x = Sampler(energy_muon, baseline)
 ###########################
 
 # Smear the stored muon energy by 10% uniform spread
-x.set_accelerator_energy(spread=0.1 * energy_muon) # GeV
+#x.set_accelerator_energy(spread=0.1 * energy_muon) # GeV
 
 #  Integrate over the detector volume
-
+my_mass = 1.3 # kt
 x.set_detector(radius=2.5, # m
-    mass=1.3, # kt
+    mass=my_mass, # kt
     density=7.8)  # g/cm^3
 
 #  Integrate over the detector straight
@@ -35,8 +35,8 @@ x.set_accelerator_length(0.15) # km
 
 #  Set the Twiss parameters (ie. accelerator optics).  This doesn't matter
 #  much but is here for complessness.
-#x.set_accelerator_twiss(emittance=2.1e-06,
-#    beta=0.04) # km, km
+x.set_accelerator_twiss(emittance=2.1e-06,
+    beta=0.04) # km, km
 
 #  Sample N points
 results = x.sample(N=1000)
@@ -50,4 +50,4 @@ results = compute_neutrino_flux(results, N_mu=1.8e18) # 1/m2
 #  Create plots and flux files
 Output.create_plot('nustorm', results)
 
-Output.print_events_to_screen(CC(results))
\ No newline at end of file
+Output.print_events_to_screen(CC(results, mass=my_mass))
