@@ -84,7 +84,7 @@ class Sampler(object):
             self.detector_max_z /= self.detector_density
             self.detector_max_z /= (2 * self.detector_radius) ** 2
 
-            print 'max_detector_z', self.detector_max_z
+            #print 'max_detector_z', self.detector_max_z
 
     def sample_accelerator(self, nbins):
         """Sample a point in the accelerator phasespace
